@@ -1,4 +1,4 @@
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 
 __author__ = 'Fernando Celmer <email@fernandocelmer.com>'
 __copyright__ = """MIT License
@@ -25,8 +25,7 @@ SOFTWARE."""
 
 
 __info__ = """
-
-Help: linuxp-plugin --help
+Help: linuxp_plugin --help
 Docs: https://docs.linuxprofile.com/
 =====================================
 """
